@@ -7,10 +7,7 @@ Usage::
     import boto3
     from mypy_boto3_batch import BatchClient
 
-    session = boto3.Session()
-
     client: BatchClient = boto3.client("batch")
-    session_client: BatchClient = session.client("batch")
     ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
@@ -65,19 +62,19 @@ class Exceptions:
 
 class BatchClient:
     """
-    [Batch.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/batch.html#Batch.Client)
+    [Batch.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/batch.html#Batch.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/batch.html#Batch.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/batch.html#Batch.Client.can_paginate)
         """
 
     def cancel_job(self, jobId: str, reason: str) -> Dict[str, Any]:
         """
-        [Client.cancel_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/batch.html#Batch.Client.cancel_job)
+        [Client.cancel_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/batch.html#Batch.Client.cancel_job)
         """
 
     def create_compute_environment(
@@ -89,7 +86,7 @@ class BatchClient:
         computeResources: "ComputeResourceTypeDef" = None,
     ) -> CreateComputeEnvironmentResponseTypeDef:
         """
-        [Client.create_compute_environment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/batch.html#Batch.Client.create_compute_environment)
+        [Client.create_compute_environment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/batch.html#Batch.Client.create_compute_environment)
         """
 
     def create_job_queue(
@@ -100,29 +97,29 @@ class BatchClient:
         state: Literal["ENABLED", "DISABLED"] = None,
     ) -> CreateJobQueueResponseTypeDef:
         """
-        [Client.create_job_queue documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/batch.html#Batch.Client.create_job_queue)
+        [Client.create_job_queue documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/batch.html#Batch.Client.create_job_queue)
         """
 
     def delete_compute_environment(self, computeEnvironment: str) -> Dict[str, Any]:
         """
-        [Client.delete_compute_environment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/batch.html#Batch.Client.delete_compute_environment)
+        [Client.delete_compute_environment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/batch.html#Batch.Client.delete_compute_environment)
         """
 
     def delete_job_queue(self, jobQueue: str) -> Dict[str, Any]:
         """
-        [Client.delete_job_queue documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/batch.html#Batch.Client.delete_job_queue)
+        [Client.delete_job_queue documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/batch.html#Batch.Client.delete_job_queue)
         """
 
     def deregister_job_definition(self, jobDefinition: str) -> Dict[str, Any]:
         """
-        [Client.deregister_job_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/batch.html#Batch.Client.deregister_job_definition)
+        [Client.deregister_job_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/batch.html#Batch.Client.deregister_job_definition)
         """
 
     def describe_compute_environments(
         self, computeEnvironments: List[str] = None, maxResults: int = None, nextToken: str = None
     ) -> DescribeComputeEnvironmentsResponseTypeDef:
         """
-        [Client.describe_compute_environments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/batch.html#Batch.Client.describe_compute_environments)
+        [Client.describe_compute_environments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/batch.html#Batch.Client.describe_compute_environments)
         """
 
     def describe_job_definitions(
@@ -134,19 +131,19 @@ class BatchClient:
         nextToken: str = None,
     ) -> DescribeJobDefinitionsResponseTypeDef:
         """
-        [Client.describe_job_definitions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/batch.html#Batch.Client.describe_job_definitions)
+        [Client.describe_job_definitions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/batch.html#Batch.Client.describe_job_definitions)
         """
 
     def describe_job_queues(
         self, jobQueues: List[str] = None, maxResults: int = None, nextToken: str = None
     ) -> DescribeJobQueuesResponseTypeDef:
         """
-        [Client.describe_job_queues documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/batch.html#Batch.Client.describe_job_queues)
+        [Client.describe_job_queues documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/batch.html#Batch.Client.describe_job_queues)
         """
 
     def describe_jobs(self, jobs: List[str]) -> DescribeJobsResponseTypeDef:
         """
-        [Client.describe_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/batch.html#Batch.Client.describe_jobs)
+        [Client.describe_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/batch.html#Batch.Client.describe_jobs)
         """
 
     def generate_presigned_url(
@@ -157,7 +154,7 @@ class BatchClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/batch.html#Batch.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/batch.html#Batch.Client.generate_presigned_url)
         """
 
     def list_jobs(
@@ -172,7 +169,7 @@ class BatchClient:
         nextToken: str = None,
     ) -> ListJobsResponseTypeDef:
         """
-        [Client.list_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/batch.html#Batch.Client.list_jobs)
+        [Client.list_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/batch.html#Batch.Client.list_jobs)
         """
 
     def register_job_definition(
@@ -186,7 +183,7 @@ class BatchClient:
         timeout: "JobTimeoutTypeDef" = None,
     ) -> RegisterJobDefinitionResponseTypeDef:
         """
-        [Client.register_job_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/batch.html#Batch.Client.register_job_definition)
+        [Client.register_job_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/batch.html#Batch.Client.register_job_definition)
         """
 
     def submit_job(
@@ -203,12 +200,12 @@ class BatchClient:
         timeout: "JobTimeoutTypeDef" = None,
     ) -> SubmitJobResponseTypeDef:
         """
-        [Client.submit_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/batch.html#Batch.Client.submit_job)
+        [Client.submit_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/batch.html#Batch.Client.submit_job)
         """
 
     def terminate_job(self, jobId: str, reason: str) -> Dict[str, Any]:
         """
-        [Client.terminate_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/batch.html#Batch.Client.terminate_job)
+        [Client.terminate_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/batch.html#Batch.Client.terminate_job)
         """
 
     def update_compute_environment(
@@ -219,7 +216,7 @@ class BatchClient:
         serviceRole: str = None,
     ) -> UpdateComputeEnvironmentResponseTypeDef:
         """
-        [Client.update_compute_environment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/batch.html#Batch.Client.update_compute_environment)
+        [Client.update_compute_environment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/batch.html#Batch.Client.update_compute_environment)
         """
 
     def update_job_queue(
@@ -230,7 +227,7 @@ class BatchClient:
         computeEnvironmentOrder: List["ComputeEnvironmentOrderTypeDef"] = None,
     ) -> UpdateJobQueueResponseTypeDef:
         """
-        [Client.update_job_queue documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/batch.html#Batch.Client.update_job_queue)
+        [Client.update_job_queue documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/batch.html#Batch.Client.update_job_queue)
         """
 
     @overload
@@ -238,7 +235,7 @@ class BatchClient:
         self, operation_name: Literal["describe_compute_environments"]
     ) -> DescribeComputeEnvironmentsPaginator:
         """
-        [Paginator.DescribeComputeEnvironments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/batch.html#Batch.Paginator.DescribeComputeEnvironments)
+        [Paginator.DescribeComputeEnvironments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/batch.html#Batch.Paginator.DescribeComputeEnvironments)
         """
 
     @overload
@@ -246,7 +243,7 @@ class BatchClient:
         self, operation_name: Literal["describe_job_definitions"]
     ) -> DescribeJobDefinitionsPaginator:
         """
-        [Paginator.DescribeJobDefinitions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/batch.html#Batch.Paginator.DescribeJobDefinitions)
+        [Paginator.DescribeJobDefinitions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/batch.html#Batch.Paginator.DescribeJobDefinitions)
         """
 
     @overload
@@ -254,11 +251,11 @@ class BatchClient:
         self, operation_name: Literal["describe_job_queues"]
     ) -> DescribeJobQueuesPaginator:
         """
-        [Paginator.DescribeJobQueues documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/batch.html#Batch.Paginator.DescribeJobQueues)
+        [Paginator.DescribeJobQueues documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/batch.html#Batch.Paginator.DescribeJobQueues)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_jobs"]) -> ListJobsPaginator:
         """
-        [Paginator.ListJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/batch.html#Batch.Paginator.ListJobs)
+        [Paginator.ListJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/batch.html#Batch.Paginator.ListJobs)
         """
